@@ -30,7 +30,7 @@ import           Hakyll.Core.Dependencies
 import           Hakyll.Core.Identifier
 import           Hakyll.Core.Item
 import           Hakyll.Core.Item.SomeItem
-import           Hakyll.Core.Logger            (Logger, Verbosity)
+import           Hakyll.Core.Logger            (Logger)
 import qualified Hakyll.Core.Logger            as Logger
 import           Hakyll.Core.Provider
 import           Hakyll.Core.Routes
@@ -42,10 +42,9 @@ import           Hakyll.Core.Writable
 
 
 --------------------------------------------------------------------------------
-run :: Configuration -> Verbosity -> Rules a -> IO (ExitCode, RuleSet)
-run config verbosity rules = do
+run :: Configuration -> Logger -> Rules a -> IO (ExitCode, RuleSet)
+run config logger rules = do
     -- Initialization
-    logger <- Logger.new verbosity
     Logger.header logger "Initialising..."
     Logger.message logger "Creating store..."
     store <- Store.new (inMemoryCache config) $ storeDirectory config
@@ -71,9 +70,10 @@ run config verbosity rules = do
             , runtimeUniverse      = M.fromList compilers
             }
         state     = RuntimeState
-            { runtimeDone  = S.empty
-            , runtimeTodo  = M.empty
-            , runtimeFacts = oldFacts
+            { runtimeDone      = S.empty
+            , runtimeSnapshots = S.empty
+            , runtimeTodo      = M.empty
+            , runtimeFacts     = oldFacts
             }
 
     -- Run the program and fetch the resulting state
@@ -109,9 +109,10 @@ data RuntimeRead = RuntimeRead
 
 --------------------------------------------------------------------------------
 data RuntimeState = RuntimeState
-    { runtimeDone  :: Set Identifier
-    , runtimeTodo  :: Map Identifier (Compiler SomeItem)
-    , runtimeFacts :: DependencyFacts
+    { runtimeDone      :: Set Identifier
+    , runtimeSnapshots :: Set (Identifier, Snapshot)
+    , runtimeTodo      :: Map Identifier (Compiler SomeItem)
+    , runtimeFacts     :: DependencyFacts
     }
 
 
@@ -204,6 +205,16 @@ chase trail id'
                 "Compiler failed but no info given, try running with -v?"
             CompilerError es -> throwError $ intercalate "; " es
 
+            -- Signal that a snapshot was saved ->
+            CompilerSnapshot snapshot c -> do
+                -- Update info. The next 'chase' will pick us again at some
+                -- point so we can continue then.
+                modify $ \s -> s
+                    { runtimeSnapshots =
+                        S.insert (id', snapshot) (runtimeSnapshots s)
+                    , runtimeTodo      = M.insert id' c (runtimeTodo s)
+                    }
+
             -- Huge success
             CompilerDone (SomeItem item) cwrite -> do
                 -- Print some info
@@ -243,7 +254,16 @@ chase trail id'
             -- Try something else first
             CompilerRequire dep c -> do
                 -- Update the compiler so we don't execute it twice
-                depDone <- (dep `S.member`) . runtimeDone <$> get
+                let (depId, depSnapshot) = dep
+                done      <- runtimeDone <$> get
+                snapshots <- runtimeSnapshots <$> get
+
+                -- Done if we either completed the entire item (runtimeDone) or
+                -- if we previously saved the snapshot (runtimeSnapshots).
+                let depDone =
+                        depId `S.member` done ||
+                        (depId, depSnapshot) `S.member` snapshots
+
                 modify $ \s -> s
                     { runtimeTodo = M.insert id'
                         (if depDone then c else compilerResult result)
@@ -252,6 +272,7 @@ chase trail id'
 
                 -- If the required item is already compiled, continue, or, start
                 -- chasing that
-                Logger.debug logger $ "Require " ++ show dep ++ ": " ++
+                Logger.debug logger $ "Require " ++ show depId ++
+                    " (snapshot " ++ depSnapshot ++ "): " ++
                     (if depDone then "OK" else "chasing")
-                if depDone then chase trail id' else chase (id' : trail) dep
+                if depDone then chase trail id' else chase (id' : trail) depId
