@@ -1,3 +1,5 @@
+{-# LANGUAGE CPP #-}
+
 --------------------------------------------------------------------------------
 -- | A Compiler that supports unix filters.
 module Hakyll.Core.UnixFilter
@@ -20,7 +22,6 @@ import           System.IO               (Handle, hClose, hFlush, hGetContents,
                                           hPutStr, hSetEncoding, localeEncoding)
 import           System.Process
 
-
 --------------------------------------------------------------------------------
 import           Hakyll.Core.Compiler
 
@@ -105,8 +106,22 @@ unixFilterIO :: Monoid o
              -> i
              -> IO (o, String, ExitCode)
 unixFilterIO writer reader programName args input = do
+    -- The problem on Windows is that `proc` is unable to execute
+    -- batch stubs (eg. anything created using 'gem install ...') even if its in
+    -- `$PATH`. A solution to this issue is to execute the batch file explicitly
+    -- using `cmd /c batchfile` but there is no rational way to know where said
+    -- batchfile is on the system. Hence, we detect windows using the
+    -- CPP and instead of using `proc` to create the process, use `shell`
+    -- which will be able to execute everything `proc` can
+    -- as well as batch files.
+#ifdef mingw32_HOST_OS
+    let pr = shell $ unwords (programName : args)
+#else
+    let pr = proc programName args
+#endif
+
     (Just inh, Just outh, Just errh, pid) <-
-        createProcess (proc programName args)
+        createProcess pr
                 { std_in  = CreatePipe
                 , std_out = CreatePipe
                 , std_err = CreatePipe
