@@ -1,4 +1,5 @@
 --------------------------------------------------------------------------------
+{-# LANGUAGE CPP                       #-}
 {-# LANGUAGE ExistentialQuantification #-}
 module Hakyll.Web.Template.Context
     ( ContextField (..)
@@ -20,6 +21,7 @@ module Hakyll.Web.Template.Context
     , dateField
     , dateFieldWith
     , getItemUTC
+    , getItemModificationTime
     , modificationTimeField
     , modificationTimeFieldWith
     , teaserField
@@ -29,16 +31,16 @@ module Hakyll.Web.Template.Context
 
 
 --------------------------------------------------------------------------------
-import           Control.Applicative           (Alternative (..), (<$>), pure)
+import           Control.Applicative           (Alternative (..), pure, (<$>))
 import           Control.Monad                 (msum)
 import           Data.List                     (intercalate)
 import qualified Data.Map                      as M
 import           Data.Monoid                   (Monoid (..))
 import           Data.Time.Clock               (UTCTime (..))
-import           Data.Time.Format              (formatTime, parseTime)
-import           System.FilePath               (takeBaseName, splitDirectories)
+import           Data.Time.Format              (formatTime)
+import qualified Data.Time.Format              as TF
 import           Data.Time.Locale.Compat       (TimeLocale, defaultTimeLocale)
-
+import           System.FilePath               (splitDirectories, takeBaseName)
 
 --------------------------------------------------------------------------------
 import           Hakyll.Core.Compiler
@@ -47,7 +49,7 @@ import           Hakyll.Core.Identifier
 import           Hakyll.Core.Item
 import           Hakyll.Core.Metadata
 import           Hakyll.Core.Provider
-import           Hakyll.Core.Util.String       (splitAll, needlePrefix)
+import           Hakyll.Core.Util.String       (needlePrefix, splitAll)
 import           Hakyll.Web.Html
 
 
@@ -238,7 +240,7 @@ titleField = mapContext takeBaseName . pathField
 -- Alternatively, when the metadata has a field called @path@ in a
 -- @folder/yyyy-mm-dd-title.extension@ format (the convention for pages)
 -- and no @published@ metadata field set, this function can render
--- the date. This pattern matches the file name or directory names 
+-- the date. This pattern matches the file name or directory names
 -- that begins with @yyyy-mm-dd@ . For example:
 -- @folder//yyyy-mm-dd-title//dist//main.extension@ .
 -- In case of multiple matches, the rightmost one is used.
@@ -282,7 +284,7 @@ getItemUTC locale id' = do
   where
     empty'     = fail $ "Hakyll.Web.Template.Context.getItemUTC: " ++
         "could not parse time for " ++ show id'
-    parseTime' = parseTime locale
+    parseTime' = parseTimeM True locale
     formats    =
         [ "%a, %d %b %Y %H:%M:%S %Z"
         , "%Y-%m-%dT%H:%M:%S%Z"
@@ -294,6 +296,17 @@ getItemUTC locale id' = do
         ]
 
 
+--------------------------------------------------------------------------------
+-- | Get the time on which the actual file was last modified. This only works if
+-- there actually is an underlying file, of couse.
+getItemModificationTime
+    :: Identifier
+    -> Compiler UTCTime
+getItemModificationTime identifier = do
+    provider <- compilerProvider <$> compilerAsk
+    return $ resourceModificationTime provider identifier
+
+
 --------------------------------------------------------------------------------
 modificationTimeField :: String     -- ^ Key
                       -> String     -- ^ Format
@@ -307,8 +320,7 @@ modificationTimeFieldWith :: TimeLocale  -- ^ Time output locale
                           -> String      -- ^ Format
                           -> Context a   -- ^ Resulting context
 modificationTimeFieldWith locale key fmt = field key $ \i -> do
-    provider <- compilerProvider <$> compilerAsk
-    let mtime = resourceModificationTime provider $ itemIdentifier i
+    mtime <- getItemModificationTime $ itemIdentifier i
     return $ formatTime locale fmt mtime
 
 
@@ -345,3 +357,10 @@ missingField :: Context a
 missingField = Context $ \k _ i -> fail $
     "Missing field $" ++ k ++ "$ in context for item " ++
     show (itemIdentifier i)
+
+parseTimeM :: Bool -> TimeLocale -> String -> String -> Maybe UTCTime
+#if MIN_VERSION_time(1,5,0)
+parseTimeM = TF.parseTimeM
+#else
+parseTimeM _ = TF.parseTime
+#endif
