@@ -26,9 +26,20 @@ import           TestSuite.Util
 
 --------------------------------------------------------------------------------
 tests :: Test
-tests = testGroup "Hakyll.Core.Template.Tests"
-    [ testCase "case01"                case01
-    , testCase "applyJoinTemplateList" testApplyJoinTemplateList
+tests = testGroup "Hakyll.Core.Template.Tests" $ concat
+    [ [ testCase "case01"                case01
+      , testCase "applyJoinTemplateList" testApplyJoinTemplateList
+      ]
+
+    , fromAssertions "readTemplate"
+        [ Template [Chunk "Hello ", Expr (Call "guest" [])]
+            @=?  readTemplate "Hello $guest()$"
+        , Template
+            [If (Call "a" [StringLiteral "bar"])
+                (Template [Chunk "foo"])
+                Nothing]
+            @=?  readTemplate "$if(a(\"bar\"))$foo$endif$"
+        ]
     ]
 
 
@@ -44,8 +55,6 @@ case01 = do
     item <- testCompilerDone store provider "example.md"    $
         pandocCompiler >>= applyTemplate (itemBody tpl) testContext
 
-    writeFile "foo" (itemBody item)
-
     out @=? itemBody item
     cleanTestEnv
 
@@ -76,4 +85,4 @@ testApplyJoinTemplateList = do
   where
     i1  = Item "item1" "Hello"
     i2  = Item "item2" "World"
-    tpl = Template [Chunk "<b>", Key "body", Chunk "</b>"]
+    tpl = Template [Chunk "<b>", Expr (Ident "body"), Chunk "</b>"]
